==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ApmReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ApmReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A reference to the APM
 * @property resourceId Resource Id of the APM
 */
public data class ApmReferenceArgs(
    public val resourceId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ApmReferenceArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.ApmReferenceArgs =
        com.pulumi.azurenative.appplatform.inputs.ApmReferenceArgs.builder()
            .resourceId(resourceId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApmReferenceArgs].
 */
@PulumiTagMarker
public class ApmReferenceArgsBuilder internal constructor() {
    private var resourceId: Output<String>? = null

    /**
     * @param value Resource Id of the APM
     */
    @JvmName("xaixcgdbkjkfurdj")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Resource Id of the APM
     */
    @JvmName("aelpmwkdkjkbkqey")
    public suspend fun resourceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): ApmReferenceArgs = ApmReferenceArgs(
        resourceId = resourceId ?: throw PulumiNullFieldException("resourceId"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/ApmReferenceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.ApmReferenceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * A reference to the APM
 * @property resourceId Resource Id of the APM
 */
public data class ApmReferenceArgs(
    public val resourceId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.ApmReferenceArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.ApmReferenceArgs =
        com.pulumi.azurenative.appplatform.inputs.ApmReferenceArgs.builder()
            .resourceId(resourceId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ApmReferenceArgs].
 */
@PulumiTagMarker
public class ApmReferenceArgsBuilder internal constructor() {
    private var resourceId: Output<String>? = null

    /**
     * @param value Resource Id of the APM
     */
    @JvmName("nnprposyhoaasgxn")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Resource Id of the APM
     */
    @JvmName("carimqhfagjfqojh")
    public suspend fun resourceId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): ApmReferenceArgs = ApmReferenceArgs(
        resourceId = resourceId ?: throw PulumiNullFieldException("resourceId"),
    )
}
